@@ -1,4 +1,7 @@
-class Bernoulli:
+from pdlpy.distribution import Distribution
+
+
+class Bernoulli(Distribution):
     """
     Discrete probability distribution of a random variable X which takes either value 1 or 0
     """
@@ -8,9 +11,15 @@ class Bernoulli:
         Parameters
         p: the probability of positive outcome of an experiment
         """
-        self.p = p
-        self.mean = p
-        self.var = p * (1 - p)
+        self._p = p
+        self._mean = p
+        self._var = p * (1 - p)
+
+    def __str__(self):
+        p = round(self._p, 2)
+        mean = round(self._mean, 2)
+        var = round(self._var, 2)
+        return f"Bernoulli(p={p}, mean={mean}, var={var})"
 
     def pmf(self, x):
         """
@@ -23,9 +32,9 @@ class Bernoulli:
         the probability that X will take a value exactly equal to x
         """
         if x == 0:
-            return 1.0 - self.p
+            return 1.0 - self._p
         else:
-            return self.p
+            return self._p
 
     def cdf(self, x):
         """
@@ -38,6 +47,6 @@ class Bernoulli:
         the probability that X will take a value less than or equal to x
         """
         if x == 0:
-            return 1.0 - self.p
+            return 1.0 - self._p
         else:
             return 1.0
