@@ -1,7 +1,8 @@
 from pdlpy.combinatorics import ncr
+from pdlpy.distribution import Distribution
 
 
-class Binomial:
+class Binomial(Distribution):
     """
     Discrete probability distribution of a number of successes in a sequence of independent experiments
     """
@@ -12,10 +13,17 @@ class Binomial:
         n: the size of the sequence
         p: the probability of success
         """
-        self.n = n
-        self.p = p
-        self.mean = n * p
-        self.var = n * p * (1 - p)
+        self._n = n
+        self._p = p
+        self._mean = n * p
+        self._var = n * p * (1 - p)
+
+    def __str__(self):
+        n = round(self._n, 2)
+        p = round(self._p, 2)
+        mean = round(self._mean, 2)
+        var = round(self._var, 2)
+        return f"Binomial(n={n}, p={p}, mean={mean}, var={var})"
 
     def pmf(self, x):
         """
@@ -27,7 +35,7 @@ class Binomial:
         Returns
         the probability that X will take a value exactly equal to x
         """
-        return ncr(self.n, x) * self.p ** x * (1 - self.p) ** (self.n - x)
+        return ncr(self._n, x) * self._p ** x * (1 - self._p) ** (self._n - x)
 
     def cdf(self, x):
         """
