@@ -1,7 +1,9 @@
 import math
 
+from pdlpy.distribution import Distribution
 
-class Exponential:
+
+class Exponential(Distribution):
     """
     Continuous probability distribution of time between events in a Poisson process
     """
@@ -11,9 +13,15 @@ class Exponential:
         Paramters
         rate: the average number of events
         """
-        self.rate = rate
-        self.mean = rate ** -1
-        self.var = rate ** -2
+        self._rate = rate
+        self._mean = rate ** -1
+        self._var = rate ** -2
+
+    def __str__(self):
+        rate = round(self._rate, 2)
+        mean = round(self._mean, 2)
+        var = round(self._var, 2)
+        return f"Exponential(rate={rate}, mean={mean}, var={var})"
 
     def pdf(self, x):
         """
@@ -25,7 +33,7 @@ class Exponential:
         Returns
         the relative likelihood that a value of X would lie in sample space
         """
-        return self.rate * math.e ** (-self.rate * x)
+        return self._rate * math.e ** (-self._rate * x)
 
     def cdf(self, x):
         """
@@ -37,4 +45,4 @@ class Exponential:
         Returns
         the probability that X will take a value less than or equal to x
         """
-        return 1 - math.e ** (-self.rate * x)
+        return 1 - math.e ** (-self._rate * x)
