@@ -1,4 +1,7 @@
-class Geometric:
+from pdlpy.distribution import Distribution
+
+
+class Geometric(Distribution):
     """
     Discrete probability distributions of the random number X of Bernoulli trials needed to get a single success
     """
@@ -8,9 +11,15 @@ class Geometric:
         Parameters
         p: the probability of the positive outcome of the experiment
         """
-        self.p = p
-        self.mean = 1 / p
-        self.var = (1 - p) / (p ** 2)
+        self._p = p
+        self._mean = 1 / p
+        self._var = (1 - p) / (p ** 2)
+
+    def __str__(self):
+        p = round(self._p, 2)
+        mean = round(self._mean, 2)
+        var = round(self._var, 2)
+        return f"Geometric(p={p}, mean={mean}, var={var})"
 
     def pmf(self, x):
         """
@@ -22,7 +31,7 @@ class Geometric:
         Returns
         the probability that X will take a value exactly equal to x
         """
-        return (1 - self.p) ** x * self.p
+        return (1 - self._p) ** x * self._p
 
     def cdf(self, x):
         """
