@@ -1,4 +1,7 @@
-class Uniform:
+from pdlpy.distribution import Distribution
+
+
+class Uniform(Distribution):
     """
     Continuous distribution of a random variable X in interval [a; b] where any value of X has an equal probability
     """
@@ -9,12 +12,19 @@ class Uniform:
         a: the minimum value of X
         b: the maximum value of X
         """
-        self.a = a
-        self.b = b
-        self.mean = (a + b) / 2
-        self.var = (b - a) ** 2 / 12
+        self._a = a
+        self._b = b
+        self._mean = (a + b) / 2
+        self._var = (b - a) ** 2 / 12
 
-    def pdf(self, x):
+    def __str__(self):
+        a = round(self._a, 2)
+        b = round(self._b, 2)
+        mean = round(self._mean, 2)
+        var = round(self._var, 2)
+        return f"Uniform(a={a}, b={b}, mean={mean}, var={var})"
+
+    def pdf(self, x=None):
         """
         Probability Density Function
 
@@ -24,7 +34,7 @@ class Uniform:
         Returns
         the relative likelihood that a value of X would lie in sample space
         """
-        return 1 / (self.b - self.a)
+        return 1 / (self._b - self._a)
 
     def cdf(self, x):
         """
@@ -36,9 +46,9 @@ class Uniform:
         Returns
         the probability that X will take a value less than or equal to x
         """
-        if x <= self.a:
+        if x <= self._a:
             return 0.0
-        elif x >= self.b:
+        elif x >= self._b:
             return 1.0
         else:
-            return (x - self.a) / (self.b - self.a)
+            return (x - self._a) / (self._b - self._a)
